@@ -24,7 +24,7 @@
  */
 #ifndef GUM_EXCEPTIONS_H
 #define GUM_EXCEPTIONS_H
-// WARNING : Do not include this file directlty : instead include
+// WARNING : Do not include this file directly : instead include
 // <agrum/config.h>
 
 #include <iomanip>
@@ -33,52 +33,66 @@
 
 #include <agrum/core/types.h>
 
-#ifdef NDEBUG
-#define GUM_ERROR_IN_EXPR( type, msg ) throw( type( msg ) )
-#define GUM_ERROR( type, msg )                                  \
-  {                                                             \
-    std::ostringstream __error__str;                            \
-    __error__str << __FILE__ << ":" << __LINE__ << ": " << msg; \
-    throw( type( __error__str.str() ) );                        \
-  }
-#define GUM_SHOWERROR( e )                                               \
-  {                                                                      \
-    std::cout << std::endl                                               \
-              << __FILE__ << ":" << __LINE__ << " " << ( e ).errorType() \
-              << " from " << std::endl                                   \
-              << ( e ).errorContent() << std::endl;                      \
-  }
-#else
-#define GUM_ERROR_IN_EXPR( type, msg ) throw( type( msg ) )
-#define GUM_ERROR( type, msg )                                      \
-  {                                                                 \
-    std::ostringstream __error__str;                                \
-    __error__str << msg;                                            \
-    throw( type( gum::__createMsg(                                  \
-        __FILE__, __FUNCTION__, __LINE__, __error__str.str() ) ) ); \
-  }
-#define GUM_SHOWERROR( e )                                               \
-  {                                                                      \
-    std::cout << std::endl                                               \
-              << __FILE__ << ":" << __LINE__ << " " << ( e ).errorType() \
-              << " from " << std::endl                                   \
-              << ( e ).errorContent() << std::endl;                      \
-    std::cout << ( e ).errorCallStack() << std::endl;                    \
-  }
-#endif  // NDEBUG
+#define GUM_ERROR_IN_EXPR(type, msg) throw(type(msg))
 
-#define GUM_MAKE_ERROR( TYPE, SUPERCLASS, MSG )       \
-  class TYPE : public SUPERCLASS {                    \
-    public:                                           \
-    TYPE( std::string aMsg, std::string aType = MSG ) \
-        : SUPERCLASS( aMsg, aType ){};                \
+#ifdef SWIG
+#  define GUM_ERROR(type, msg)         \
+    {                                  \
+      std::ostringstream __error__str; \
+      __error__str << msg;             \
+      throw(type(__error__str.str())); \
+    }
+#  define GUM_SHOWERROR(e)                                                      \
+    {                                                                           \
+      std::cout << std::endl                                                    \
+                << (e).errorType() << " : " << (e).errorContent() << std::endl; \
+    }
+#else
+#  ifdef NDEBUG
+#    define GUM_ERROR(type, msg)                                    \
+      {                                                             \
+        std::ostringstream __error__str;                            \
+        __error__str << __FILE__ << ":" << __LINE__ << ": " << msg; \
+        throw(type(__error__str.str()));                            \
+      }
+#    define GUM_SHOWERROR(e)                                               \
+      {                                                                    \
+        std::cout << std::endl                                             \
+                  << __FILE__ << ":" << __LINE__ << " " << (e).errorType() \
+                  << " from " << std::endl                                 \
+                  << (e).errorContent() << std::endl;                      \
+      }
+#  else
+#    define GUM_ERROR(type, msg)                                   \
+      {                                                            \
+        std::ostringstream __error__str;                           \
+        __error__str << msg;                                       \
+        throw(type(gum::__createMsg(                               \
+          __FILE__, __FUNCTION__, __LINE__, __error__str.str()))); \
+      }
+#    define GUM_SHOWERROR(e)                                               \
+      {                                                                    \
+        std::cout << std::endl                                             \
+                  << __FILE__ << ":" << __LINE__ << " " << (e).errorType() \
+                  << " from " << std::endl                                 \
+                  << (e).errorContent() << std::endl;                      \
+        std::cout << (e).errorCallStack() << std::endl;                    \
+      }
+#  endif   // NDEBUG
+#endif     // SWIG
+
+#define GUM_MAKE_ERROR(TYPE, SUPERCLASS, MSG)                                    \
+  class TYPE : public SUPERCLASS {                                               \
+    public:                                                                      \
+    TYPE(std::string aMsg, std::string aType = MSG) : SUPERCLASS(aMsg, aType){}; \
+    TYPE(const TYPE& src) : SUPERCLASS(src){};                                   \
   };
 
-#define GUM_SYNTAX_ERROR( msg, line, column )                      \
-  {                                                                \
-    std::ostringstream __error__str;                               \
-    __error__str << msg;                                           \
-    throw( gum::SyntaxError( __error__str.str(), line, column ) ); \
+#define GUM_SYNTAX_ERROR(msg, line, column)                    \
+  {                                                            \
+    std::ostringstream __error__str;                           \
+    __error__str << msg;                                       \
+    throw(gum::SyntaxError(__error__str.str(), line, column)); \
   }
 
 namespace gum {
@@ -87,7 +101,6 @@ namespace gum {
    * @brief Base class for all aGrUM's exceptions.
    */
   class Exception {
-
     protected:
     std::string _msg;
     std::string _type;
@@ -98,16 +111,19 @@ namespace gum {
     /// @name Class constructors & destructors
     // ====================================================================
     /// @{
-    Exception( const std::string aMsg = "",
-               const std::string aType = "Generic error" );
+    Exception(const std::string aMsg = "",
+              const std::string aType = "Generic error");
 
-    Exception( const Exception& e );
+    Exception(const Exception& e);
 
     ~Exception() {}
 
-    /// @}
-
-    const std::string toString() const { return _msg; }
+/// @}
+#ifdef SWIG
+    const std::string what() const { return "[pyAgrum] " + _type + ": " + _msg; }
+#else
+    const std::string what() const { return "[pyAgrum] " + _type + " : " + _msg; }
+#endif
 
     /**
      * @brief Returns the message content.
@@ -128,7 +144,6 @@ namespace gum {
     const std::string errorCallStack() const { return _callstack; }
   };
 
-
   /**
    * @class gum::IdError agrum/core/exceptions.h
    * @extends gum::Exception
@@ -150,7 +165,6 @@ namespace gum {
    */
   class UndefinedIteratorValue;
 
-
   /**
    * @class gum::UndefinedIteratorKey agrum/core/exceptions.h
    * @extends gum::Exception
@@ -209,7 +223,6 @@ namespace gum {
    */
   class IOError;
 
-
   /**
    * @class gum::FormatNotFound agrum/core/exceptions.h
    * @extends gum::Exception
@@ -344,7 +357,6 @@ namespace gum {
    */
   class InvalidDirectedCycle;
 
-
   ///////////////////////////////////
   /**
    * @class gum::CPTError agrum/core/exceptions.h
@@ -445,71 +457,92 @@ namespace gum {
   class UnknownLabelInDatabase;
 
   /**
-   * @class gum::SyntaxError exceptions.h <agrum/core/exceptions.h>
+   * @class gum::MissingValueInDatabase agrum/core/exceptions.h
+   * @extends gum::LearningError
+   * Error: The database contains some missing values
+   */
+  class MissingValueInDatabase;
+
+
+  /**
+   * @class gum::SyntaxError
+   * @headerfile exceptions.h <agrum/core/exceptions.h>
    * @extends gum::IOError
    * Special exception for syntax errors in files.
    */
   class SyntaxError;
 
+  /**
+   * @class gum::NotImplementedYet agrum/core/exceptions.h
+   * @extends gum::Exception
+   * Exception : there is something wrong with an arc
+   */
+  class NotImplementedYet;
+
+
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-  const std::string __createMsg( const std::string& filename,
-                                 const std::string& function,
-                                 const int          line,
-                                 const std::string& msg );
-  GUM_MAKE_ERROR( IdError, Exception, "ID error" )
-  GUM_MAKE_ERROR( FatalError, Exception, "Fatal error" )
-  GUM_MAKE_ERROR( UndefinedIteratorValue, Exception, "Undefined iterator" )
-  GUM_MAKE_ERROR( UndefinedIteratorKey, Exception, "Undefined iterator's key" )
-  GUM_MAKE_ERROR( NullElement, Exception, "Null element" )
-  GUM_MAKE_ERROR( UndefinedElement, Exception, "Undefined element" )
-  GUM_MAKE_ERROR( SizeError, Exception, "incorrect size" )
-  GUM_MAKE_ERROR( EmptySet, Exception, "Empty set" )
-  GUM_MAKE_ERROR( InvalidArgumentsNumber, Exception, "Invalid argument number" )
-  GUM_MAKE_ERROR( InvalidArgument, Exception, "Invalid argument" )
-  GUM_MAKE_ERROR( IOError, Exception, "I/O Error" )
-  GUM_MAKE_ERROR( FormatNotFound, IOError, "Format not found" )
-  GUM_MAKE_ERROR( OperationNotAllowed, Exception, "Operation not allowed" )
-  GUM_MAKE_ERROR( NotFound, Exception, "Object not found" )
-  GUM_MAKE_ERROR( ReferenceError, Exception, "Reference error" )
-  GUM_MAKE_ERROR( OutOfBounds, ReferenceError, "Out of bound error" )
-  GUM_MAKE_ERROR( OutOfLowerBound, OutOfBounds, "Out of lower bound error" )
-  GUM_MAKE_ERROR( OutOfUpperBound, OutOfBounds, "Out of upper bound error" )
-  GUM_MAKE_ERROR( DuplicateElement, ReferenceError, "Duplicate element" )
-  GUM_MAKE_ERROR( DuplicateLabel, ReferenceError, "Duplicate label" )
-  GUM_MAKE_ERROR( GraphError, Exception, "Graph error" )
-  GUM_MAKE_ERROR( NoNeighbour, GraphError, "No neighbour found" )
-  GUM_MAKE_ERROR( NoParent, GraphError, "No parent found" )
-  GUM_MAKE_ERROR( NoChild, GraphError, "No child found" )
-  GUM_MAKE_ERROR( InvalidEdge, GraphError, "Edge invalid" )
-  GUM_MAKE_ERROR( InvalidArc, GraphError, "Arc invalid" )
-  GUM_MAKE_ERROR( InvalidNode, GraphError, "Node invalid" )
-  GUM_MAKE_ERROR( EmptyBSTree, GraphError, "Empty binary search tree" )
-  GUM_MAKE_ERROR( DefaultInLabel, GraphError, "Error on label" )
-  GUM_MAKE_ERROR( InvalidDirectedCycle, GraphError, "Directed cycle detected" )
-  GUM_MAKE_ERROR( CPTError, Exception, "CPT error" )
-  GUM_MAKE_ERROR( CPTNoSumTo1, CPTError, "CPT does not sum to 1" )
-  GUM_MAKE_ERROR( IncompatibleEvidence,
-                  Exception,
-                  "several evidence/CPT are incompatible together (proba=0)" )
-  GUM_MAKE_ERROR( FactoryError, Exception, "factory error" )
-  GUM_MAKE_ERROR( FactoryInvalidState, FactoryError, "invalid state error" )
-  GUM_MAKE_ERROR( WrongType, FactoryError, "wrong type for this operation" )
-  GUM_MAKE_ERROR( WrongClassElement, FactoryError, "Wrong ClassElement" )
-  GUM_MAKE_ERROR( TypeError, FactoryError, "Wrong subtype or subclass" )
-  GUM_MAKE_ERROR( LearningError, Exception, "Factory error" )
-  GUM_MAKE_ERROR( IncompatibleScoreApriori,
-                  LearningError,
-                  "Incompatbile (maybe implicit) priors" )
-  GUM_MAKE_ERROR( PossiblyIncompatibleScoreApriori,
-                  LearningError,
-                  "Possible incompatibilty between score and prior" )
-  GUM_MAKE_ERROR( DatabaseError, LearningError, "Database error" )
-  GUM_MAKE_ERROR( MissingVariableInDatabase,
-                  LearningError,
-                  "Missing variable name in database" )
-  GUM_MAKE_ERROR( UnknownLabelInDatabase,
-                  LearningError,
-                  "Unknown label found in database" )
+  const std::string __createMsg(const std::string& filename,
+                                const std::string& function,
+                                const int          line,
+                                const std::string& msg);
+  GUM_MAKE_ERROR(IdError, Exception, "ID error")
+  GUM_MAKE_ERROR(FatalError, Exception, "Fatal error")
+  GUM_MAKE_ERROR(NotImplementedYet, Exception, "Not implemented yet")
+  GUM_MAKE_ERROR(UndefinedIteratorValue, Exception, "Undefined iterator")
+  GUM_MAKE_ERROR(UndefinedIteratorKey, Exception, "Undefined iterator's key")
+  GUM_MAKE_ERROR(NullElement, Exception, "Null element")
+  GUM_MAKE_ERROR(UndefinedElement, Exception, "Undefined element")
+  GUM_MAKE_ERROR(SizeError, Exception, "incorrect size")
+  GUM_MAKE_ERROR(EmptySet, Exception, "Empty set")
+  GUM_MAKE_ERROR(InvalidArgumentsNumber, Exception, "Invalid argument number")
+  GUM_MAKE_ERROR(InvalidArgument, Exception, "Invalid argument")
+  GUM_MAKE_ERROR(IOError, Exception, "I/O Error")
+  GUM_MAKE_ERROR(FormatNotFound, IOError, "Format not found")
+  GUM_MAKE_ERROR(OperationNotAllowed, Exception, "Operation not allowed")
+  GUM_MAKE_ERROR(NotFound, Exception, "Object not found")
+  GUM_MAKE_ERROR(ReferenceError, Exception, "Reference error")
+  GUM_MAKE_ERROR(OutOfBounds, ReferenceError, "Out of bound error")
+  GUM_MAKE_ERROR(OutOfLowerBound, OutOfBounds, "Out of lower bound error")
+  GUM_MAKE_ERROR(OutOfUpperBound, OutOfBounds, "Out of upper bound error")
+  GUM_MAKE_ERROR(DuplicateElement, ReferenceError, "Duplicate element")
+  GUM_MAKE_ERROR(DuplicateLabel, ReferenceError, "Duplicate label")
+  GUM_MAKE_ERROR(GraphError, Exception, "Graph error")
+  GUM_MAKE_ERROR(NoNeighbour, GraphError, "No neighbour found")
+  GUM_MAKE_ERROR(NoParent, GraphError, "No parent found")
+  GUM_MAKE_ERROR(NoChild, GraphError, "No child found")
+  GUM_MAKE_ERROR(InvalidEdge, GraphError, "Edge invalid")
+  GUM_MAKE_ERROR(InvalidArc, GraphError, "Arc invalid")
+  GUM_MAKE_ERROR(InvalidNode, GraphError, "Node invalid")
+  GUM_MAKE_ERROR(EmptyBSTree, GraphError, "Empty binary search tree")
+  GUM_MAKE_ERROR(DefaultInLabel, GraphError, "Error on label")
+  GUM_MAKE_ERROR(InvalidDirectedCycle, GraphError, "Directed cycle detected")
+  GUM_MAKE_ERROR(CPTError, Exception, "CPT error")
+  GUM_MAKE_ERROR(CPTNoSumTo1, CPTError, "CPT does not sum to 1")
+  GUM_MAKE_ERROR(IncompatibleEvidence,
+                 Exception,
+                 "several evidence/CPT are incompatible together (proba=0)")
+  GUM_MAKE_ERROR(FactoryError, Exception, "factory error")
+  GUM_MAKE_ERROR(FactoryInvalidState, FactoryError, "invalid state error")
+  GUM_MAKE_ERROR(WrongType, FactoryError, "wrong type for this operation")
+  GUM_MAKE_ERROR(WrongClassElement, FactoryError, "Wrong ClassElement")
+  GUM_MAKE_ERROR(TypeError, FactoryError, "Wrong subtype or subclass")
+  GUM_MAKE_ERROR(LearningError, Exception, "Factory error")
+  GUM_MAKE_ERROR(IncompatibleScoreApriori,
+                 LearningError,
+                 "Incompatbile (maybe implicit) priors")
+  GUM_MAKE_ERROR(PossiblyIncompatibleScoreApriori,
+                 LearningError,
+                 "Possible incompatibilty between score and prior")
+  GUM_MAKE_ERROR(DatabaseError, LearningError, "Database error")
+  GUM_MAKE_ERROR(MissingVariableInDatabase,
+                 LearningError,
+                 "Missing variable name in database")
+  GUM_MAKE_ERROR(MissingValueInDatabase,
+                 LearningError,
+                 "The database contains some missing values")
+  GUM_MAKE_ERROR(UnknownLabelInDatabase,
+                 LearningError,
+                 "Unknown label found in database")
 
   class SyntaxError : public IOError {
     protected:
@@ -517,20 +550,19 @@ namespace gum {
     Size _noCol;
 
     public:
-    SyntaxError( const std::string& aMsg,
-                 Size               nol,
-                 Size               noc,
-                 std::string        aType = "Syntax Error" )
-        : IOError( aMsg, aType )
-        , _noLine( nol )
-        , _noCol( noc ){
+    SyntaxError(const std::string& aMsg,
+                Size               nol,
+                Size               noc,
+                std::string        aType = "Syntax Error") :
+        IOError(aMsg, aType),
+        _noLine(nol), _noCol(noc){
 
-          };
+                      };
 
     Size col() const { return _noCol; };
     Size line() const { return _noLine; };
   };
-#endif  // DOXYGEN_SHOULD_SKIP_THIS
+#endif   // DOXYGEN_SHOULD_SKIP_THIS
 } /* namespace gum */
 
 #endif /* GUM_EXCEPTIONS_H */
