@@ -17,14 +17,14 @@
  * Avoiding windows.h makes it simpler to use windows sockets in conjunction
  * with dirent.h.
  */
-#if !defined( _68K_ ) && !defined( _MPPC_ ) && !defined( _X86_ ) && \
-    !defined( _IA64_ ) && !defined( _AMD64_ ) && defined( _M_IX86 )
-#define _X86_
-#endif
-#if !defined( _68K_ ) && !defined( _MPPC_ ) && !defined( _X86_ ) && \
-    !defined( _IA64_ ) && !defined( _AMD64_ ) && defined( _M_AMD64 )
-#define _AMD64_
-#endif
+#  if !defined(_68K_) && !defined(_MPPC_) && !defined(_X86_) && !defined(_IA64_) \
+    && !defined(_AMD64_) && defined(_M_IX86)
+#    define _X86_
+#  endif
+#  if !defined(_68K_) && !defined(_MPPC_) && !defined(_X86_) && !defined(_IA64_) \
+    && !defined(_AMD64_) && defined(_M_AMD64)
+#    define _AMD64_
+#  endif
 
 // clang-format off
 // clang-format may change headers order. We do not want it here.
@@ -42,145 +42,145 @@
 // clang-format on
 
 /* Indicates that d_type field is available in dirent structure */
-#define _DIRENT_HAVE_D_TYPE
+#  define _DIRENT_HAVE_D_TYPE
 
 /* Indicates that d_namlen field is available in dirent structure */
-#define _DIRENT_HAVE_D_NAMLEN
+#  define _DIRENT_HAVE_D_NAMLEN
 
 /* Entries missing from MSVC 6.0 */
-#if !defined( FILE_ATTRIBUTE_DEVICE )
-#define FILE_ATTRIBUTE_DEVICE 0x40
-#endif
+#  if !defined(FILE_ATTRIBUTE_DEVICE)
+#    define FILE_ATTRIBUTE_DEVICE 0x40
+#  endif
 
 /* File type and permission flags for stat(), general mask */
-#if !defined( S_IFMT )
-#define S_IFMT _S_IFMT
-#endif
+#  if !defined(S_IFMT)
+#    define S_IFMT _S_IFMT
+#  endif
 
 /* Directory bit */
-#if !defined( S_IFDIR )
-#define S_IFDIR _S_IFDIR
-#endif
+#  if !defined(S_IFDIR)
+#    define S_IFDIR _S_IFDIR
+#  endif
 
 /* Character device bit */
-#if !defined( S_IFCHR )
-#define S_IFCHR _S_IFCHR
-#endif
+#  if !defined(S_IFCHR)
+#    define S_IFCHR _S_IFCHR
+#  endif
 
 /* Pipe bit */
-#if !defined( S_IFFIFO )
-#define S_IFFIFO _S_IFFIFO
-#endif
+#  if !defined(S_IFFIFO)
+#    define S_IFFIFO _S_IFFIFO
+#  endif
 
 /* Regular file bit */
-#if !defined( S_IFREG )
-#define S_IFREG _S_IFREG
-#endif
+#  if !defined(S_IFREG)
+#    define S_IFREG _S_IFREG
+#  endif
 
 /* Read permission */
-#if !defined( S_IREAD )
-#define S_IREAD _S_IREAD
-#endif
+#  if !defined(S_IREAD)
+#    define S_IREAD _S_IREAD
+#  endif
 
 /* Write permission */
-#if !defined( S_IWRITE )
-#define S_IWRITE _S_IWRITE
-#endif
+#  if !defined(S_IWRITE)
+#    define S_IWRITE _S_IWRITE
+#  endif
 
 /* Execute permission */
-#if !defined( S_IEXEC )
-#define S_IEXEC _S_IEXEC
-#endif
+#  if !defined(S_IEXEC)
+#    define S_IEXEC _S_IEXEC
+#  endif
 
 /* Pipe */
-#if !defined( S_IFIFO )
-#define S_IFIFO _S_IFIFO
-#endif
+#  if !defined(S_IFIFO)
+#    define S_IFIFO _S_IFIFO
+#  endif
 
 /* Block device */
-#if !defined( S_IFBLK )
-#define S_IFBLK 0
-#endif
+#  if !defined(S_IFBLK)
+#    define S_IFBLK 0
+#  endif
 
 /* Link */
-#if !defined( S_IFLNK )
-#define S_IFLNK 0
-#endif
+#  if !defined(S_IFLNK)
+#    define S_IFLNK 0
+#  endif
 
 /* Socket */
-#if !defined( S_IFSOCK )
-#define S_IFSOCK 0
-#endif
+#  if !defined(S_IFSOCK)
+#    define S_IFSOCK 0
+#  endif
 
 /* Read user permission */
-#if !defined( S_IRUSR )
-#define S_IRUSR S_IREAD
-#endif
+#  if !defined(S_IRUSR)
+#    define S_IRUSR S_IREAD
+#  endif
 
 /* Write user permission */
-#if !defined( S_IWUSR )
-#define S_IWUSR S_IWRITE
-#endif
+#  if !defined(S_IWUSR)
+#    define S_IWUSR S_IWRITE
+#  endif
 
 /* Execute user permission */
-#if !defined( S_IXUSR )
-#define S_IXUSR 0
-#endif
+#  if !defined(S_IXUSR)
+#    define S_IXUSR 0
+#  endif
 
 /* Read group permission */
-#if !defined( S_IRGRP )
-#define S_IRGRP 0
-#endif
+#  if !defined(S_IRGRP)
+#    define S_IRGRP 0
+#  endif
 
 /* Write group permission */
-#if !defined( S_IWGRP )
-#define S_IWGRP 0
-#endif
+#  if !defined(S_IWGRP)
+#    define S_IWGRP 0
+#  endif
 
 /* Execute group permission */
-#if !defined( S_IXGRP )
-#define S_IXGRP 0
-#endif
+#  if !defined(S_IXGRP)
+#    define S_IXGRP 0
+#  endif
 
 /* Read others permission */
-#if !defined( S_IROTH )
-#define S_IROTH 0
-#endif
+#  if !defined(S_IROTH)
+#    define S_IROTH 0
+#  endif
 
 /* Write others permission */
-#if !defined( S_IWOTH )
-#define S_IWOTH 0
-#endif
+#  if !defined(S_IWOTH)
+#    define S_IWOTH 0
+#  endif
 
 /* Execute others permission */
-#if !defined( S_IXOTH )
-#define S_IXOTH 0
-#endif
+#  if !defined(S_IXOTH)
+#    define S_IXOTH 0
+#  endif
 
 /* Maximum length of file name */
-#if !defined( PATH_MAX )
-#define PATH_MAX MAX_PATH
-#endif
-#if !defined( FILENAME_MAX )
-#define FILENAME_MAX MAX_PATH
-#endif
-#if !defined( NAME_MAX )
-#define NAME_MAX FILENAME_MAX
-#endif
+#  if !defined(PATH_MAX)
+#    define PATH_MAX MAX_PATH
+#  endif
+#  if !defined(FILENAME_MAX)
+#    define FILENAME_MAX MAX_PATH
+#  endif
+#  if !defined(NAME_MAX)
+#    define NAME_MAX FILENAME_MAX
+#  endif
 
 /* File type flags for d_type */
-#define DT_UNKNOWN 0
-#define DT_REG S_IFREG
-#define DT_DIR S_IFDIR
-#define DT_FIFO S_IFIFO
-#define DT_SOCK S_IFSOCK
-#define DT_CHR S_IFCHR
-#define DT_BLK S_IFBLK
-#define DT_LNK S_IFLNK
+#  define DT_UNKNOWN 0
+#  define DT_REG S_IFREG
+#  define DT_DIR S_IFDIR
+#  define DT_FIFO S_IFIFO
+#  define DT_SOCK S_IFSOCK
+#  define DT_CHR S_IFCHR
+#  define DT_BLK S_IFBLK
+#  define DT_LNK S_IFLNK
 
 /* Macros for converting between st_mode and d_type */
-#define IFTODT( mode ) ( (mode)&S_IFMT )
-#define DTTOIF( type ) ( type )
+#  define IFTODT(mode) ((mode)&S_IFMT)
+#  define DTTOIF(type) (type)
 
 /*
  * File type macros.  Note that block devices, sockets and links cannot be
@@ -188,38 +188,38 @@
  * only defined for compatibility.  These macros should always return false
  * on Windows.
  */
-#if !defined( S_ISFIFO )
-#define S_ISFIFO( mode ) ( ( (mode)&S_IFMT ) == S_IFIFO )
-#endif
-#if !defined( S_ISDIR )
-#define S_ISDIR( mode ) ( ( (mode)&S_IFMT ) == S_IFDIR )
-#endif
-#if !defined( S_ISREG )
-#define S_ISREG( mode ) ( ( (mode)&S_IFMT ) == S_IFREG )
-#endif
-#if !defined( S_ISLNK )
-#define S_ISLNK( mode ) ( ( (mode)&S_IFMT ) == S_IFLNK )
-#endif
-#if !defined( S_ISSOCK )
-#define S_ISSOCK( mode ) ( ( (mode)&S_IFMT ) == S_IFSOCK )
-#endif
-#if !defined( S_ISCHR )
-#define S_ISCHR( mode ) ( ( (mode)&S_IFMT ) == S_IFCHR )
-#endif
-#if !defined( S_ISBLK )
-#define S_ISBLK( mode ) ( ( (mode)&S_IFMT ) == S_IFBLK )
-#endif
+#  if !defined(S_ISFIFO)
+#    define S_ISFIFO(mode) (((mode)&S_IFMT) == S_IFIFO)
+#  endif
+#  if !defined(S_ISDIR)
+#    define S_ISDIR(mode) (((mode)&S_IFMT) == S_IFDIR)
+#  endif
+#  if !defined(S_ISREG)
+#    define S_ISREG(mode) (((mode)&S_IFMT) == S_IFREG)
+#  endif
+#  if !defined(S_ISLNK)
+#    define S_ISLNK(mode) (((mode)&S_IFMT) == S_IFLNK)
+#  endif
+#  if !defined(S_ISSOCK)
+#    define S_ISSOCK(mode) (((mode)&S_IFMT) == S_IFSOCK)
+#  endif
+#  if !defined(S_ISCHR)
+#    define S_ISCHR(mode) (((mode)&S_IFMT) == S_IFCHR)
+#  endif
+#  if !defined(S_ISBLK)
+#    define S_ISBLK(mode) (((mode)&S_IFMT) == S_IFBLK)
+#  endif
 
 /* Return the exact length of d_namlen without zero terminator */
-#define _D_EXACT_NAMLEN( p ) ( ( p )->d_namlen )
+#  define _D_EXACT_NAMLEN(p) ((p)->d_namlen)
 
 /* Return number of bytes needed to store d_namlen */
-#define _D_ALLOC_NAMLEN( p ) ( PATH_MAX )
+#  define _D_ALLOC_NAMLEN(p) (PATH_MAX)
 
 
-#ifdef __cplusplus
+#  ifdef __cplusplus
 extern "C" {
-#endif
+#  endif
 
 
 /* Wide-character version */
@@ -259,19 +259,19 @@ struct _WDIR {
 };
 typedef struct _WDIR _WDIR;
 
-static _WDIR* _wopendir( const wchar_t* dirname );
-static struct _wdirent* _wreaddir( _WDIR* dirp );
-static int _wclosedir( _WDIR* dirp );
-static void _wrewinddir( _WDIR* dirp );
+static _WDIR*           _wopendir(const wchar_t* dirname);
+static struct _wdirent* _wreaddir(_WDIR* dirp);
+static int              _wclosedir(_WDIR* dirp);
+static void             _wrewinddir(_WDIR* dirp);
 
 
 /* For compatibility with Symbian */
-#define wdirent _wdirent
-#define WDIR _WDIR
-#define wopendir _wopendir
-#define wreaddir _wreaddir
-#define wclosedir _wclosedir
-#define wrewinddir _wrewinddir
+#  define wdirent _wdirent
+#  define WDIR _WDIR
+#  define wopendir _wopendir
+#  define wreaddir _wreaddir
+#  define wclosedir _wclosedir
+#  define wrewinddir _wrewinddir
 
 
 /* Multi-byte character versions */
@@ -299,48 +299,48 @@ struct DIR {
 };
 typedef struct DIR DIR;
 
-static DIR* opendir( const char* dirname );
-static struct dirent* readdir( DIR* dirp );
-static int closedir( DIR* dirp );
-static void rewinddir( DIR* dirp );
+static DIR*           opendir(const char* dirname);
+static struct dirent* readdir(DIR* dirp);
+static int            closedir(DIR* dirp);
+static void           rewinddir(DIR* dirp);
 
 
 /* Internal utility functions */
-static WIN32_FIND_DATAW* dirent_first( _WDIR* dirp );
-static WIN32_FIND_DATAW* dirent_next( _WDIR* dirp );
+static WIN32_FIND_DATAW* dirent_first(_WDIR* dirp);
+static WIN32_FIND_DATAW* dirent_next(_WDIR* dirp);
 
-static int dirent_mbstowcs_s( size_t*     pReturnValue,
-                              wchar_t*    wcstr,
-                              size_t      sizeInWords,
-                              const char* mbstr,
-                              size_t      count );
+static int dirent_mbstowcs_s(size_t*     pReturnValue,
+                             wchar_t*    wcstr,
+                             size_t      sizeInWords,
+                             const char* mbstr,
+                             size_t      count);
 
-static int dirent_wcstombs_s( size_t*        pReturnValue,
-                              char*          mbstr,
-                              size_t         sizeInBytes,
-                              const wchar_t* wcstr,
-                              size_t         count );
+static int dirent_wcstombs_s(size_t*        pReturnValue,
+                             char*          mbstr,
+                             size_t         sizeInBytes,
+                             const wchar_t* wcstr,
+                             size_t         count);
 
-static void dirent_set_errno( int error );
+static void dirent_set_errno(int error);
 
 /*
  * Open directory stream DIRNAME for read and return a pointer to the
  * internal working area that is used to retrieve individual directory
  * entries.
  */
-static _WDIR* _wopendir( const wchar_t* dirname ) {
+static _WDIR* _wopendir(const wchar_t* dirname) {
   _WDIR* dirp = NULL;
   int    error;
 
   /* Must have directory name */
-  if ( dirname == NULL || dirname[0] == '\0' ) {
-    dirent_set_errno( ENOENT );
+  if (dirname == NULL || dirname[0] == '\0') {
+    dirent_set_errno(ENOENT);
     return NULL;
   }
 
   /* Allocate new _WDIR structure */
-  dirp = (_WDIR*)malloc( sizeof( struct _WDIR ) );
-  if ( dirp != NULL ) {
+  dirp = (_WDIR*)malloc(sizeof(struct _WDIR));
+  if (dirp != NULL) {
     DWORD n;
 
     /* Reset _WDIR structure */
@@ -349,30 +349,29 @@ static _WDIR* _wopendir( const wchar_t* dirname ) {
     dirp->cached = 0;
 
     /* Compute the length of full path plus zero terminator */
-    n = GetFullPathNameW( dirname, 0, NULL, NULL );
+    n = GetFullPathNameW(dirname, 0, NULL, NULL);
 
     /* Allocate room for absolute directory name and search pattern */
-    dirp->patt = (wchar_t*)malloc( sizeof( wchar_t ) * n + 16 );
-    if ( dirp->patt ) {
-
+    dirp->patt = (wchar_t*)malloc(sizeof(wchar_t) * n + 16);
+    if (dirp->patt) {
       /*
        * Convert relative directory name to an absolute one.  This
        * allows rewinddir() to function correctly even when current
        * working directory is changed between opendir() and rewinddir().
        */
-      n = GetFullPathNameW( dirname, n, dirp->patt, NULL );
-      if ( n > 0 ) {
+      n = GetFullPathNameW(dirname, n, dirp->patt, NULL);
+      if (n > 0) {
         wchar_t* p;
 
         /* Append search pattern \* to the directory name */
         p = dirp->patt + n;
-        if ( dirp->patt < p ) {
-          switch ( p[-1] ) {
+        if (dirp->patt < p) {
+          switch (p[-1]) {
             case '\\':
             case '/':
             case ':':
-                /* Directory ends in path separator, e.g. c:\temp\ */
-                /*NOP*/;
+              /* Directory ends in path separator, e.g. c:\temp\ */
+              /*NOP*/;
               break;
 
             default:
@@ -384,18 +383,18 @@ static _WDIR* _wopendir( const wchar_t* dirname ) {
         *p = '\0';
 
         /* Open directory stream and retrieve the first entry */
-        if ( dirent_first( dirp ) ) {
+        if (dirent_first(dirp)) {
           /* Directory stream opened successfully */
           error = 0;
         } else {
           /* Cannot retrieve first entry */
           error = 1;
-          dirent_set_errno( ENOENT );
+          dirent_set_errno(ENOENT);
         }
 
       } else {
         /* Cannot retrieve full path name */
-        dirent_set_errno( ENOENT );
+        dirent_set_errno(ENOENT);
         error = 1;
       }
 
@@ -410,8 +409,8 @@ static _WDIR* _wopendir( const wchar_t* dirname ) {
   }
 
   /* Clean up in case of error */
-  if ( error && dirp ) {
-    _wclosedir( dirp );
+  if (error && dirp) {
+    _wclosedir(dirp);
     dirp = NULL;
   }
 
@@ -424,13 +423,13 @@ static _WDIR* _wopendir( const wchar_t* dirname ) {
  * this function include regular files, sub-directories, pseudo-directories
  * "." and ".." as well as volume labels, hidden files and system files.
  */
-static struct _wdirent* _wreaddir( _WDIR* dirp ) {
+static struct _wdirent* _wreaddir(_WDIR* dirp) {
   WIN32_FIND_DATAW* datap;
   struct _wdirent*  entp;
 
   /* Read next directory entry */
-  datap = dirent_next( dirp );
-  if ( datap ) {
+  datap = dirent_next(dirp);
+  if (datap) {
     size_t n;
     DWORD  attr;
 
@@ -443,7 +442,7 @@ static struct _wdirent* _wreaddir( _WDIR* dirp ) {
      * to PATH_MAX characters and zero-terminate the buffer.
      */
     n = 0;
-    while ( n + 1 < PATH_MAX && datap->cFileName[n] != 0 ) {
+    while (n + 1 < PATH_MAX && datap->cFileName[n] != 0) {
       entp->d_name[n] = datap->cFileName[n];
       n++;
     }
@@ -454,9 +453,9 @@ static struct _wdirent* _wreaddir( _WDIR* dirp ) {
 
     /* File type */
     attr = datap->dwFileAttributes;
-    if ( ( attr & FILE_ATTRIBUTE_DEVICE ) != 0 ) {
+    if ((attr & FILE_ATTRIBUTE_DEVICE) != 0) {
       entp->d_type = DT_CHR;
-    } else if ( ( attr & FILE_ATTRIBUTE_DIRECTORY ) != 0 ) {
+    } else if ((attr & FILE_ATTRIBUTE_DIRECTORY) != 0) {
       entp->d_type = DT_DIR;
     } else {
       entp->d_type = DT_REG;
@@ -464,10 +463,9 @@ static struct _wdirent* _wreaddir( _WDIR* dirp ) {
 
     /* Reset dummy fields */
     entp->d_ino = 0;
-    entp->d_reclen = sizeof( struct _wdirent );
+    entp->d_reclen = sizeof(struct _wdirent);
 
   } else {
-
     /* Last directory entry read */
     entp = NULL;
   }
@@ -480,29 +478,28 @@ static struct _wdirent* _wreaddir( _WDIR* dirp ) {
  * DIR structure as well as any directory entry read previously by
  * _wreaddir().
  */
-static int _wclosedir( _WDIR* dirp ) {
+static int _wclosedir(_WDIR* dirp) {
   int ok;
-  if ( dirp ) {
-
+  if (dirp) {
     /* Release search handle */
-    if ( dirp->handle != INVALID_HANDLE_VALUE ) {
-      FindClose( dirp->handle );
+    if (dirp->handle != INVALID_HANDLE_VALUE) {
+      FindClose(dirp->handle);
       dirp->handle = INVALID_HANDLE_VALUE;
     }
 
     /* Release search pattern */
-    if ( dirp->patt ) {
-      free( dirp->patt );
+    if (dirp->patt) {
+      free(dirp->patt);
       dirp->patt = NULL;
     }
 
     /* Release directory structure */
-    free( dirp );
+    free(dirp);
     ok = /*success*/ 0;
 
   } else {
     /* Invalid directory stream */
-    dirent_set_errno( EBADF );
+    dirent_set_errno(EBADF);
     ok = /*failure*/ -1;
   }
   return ok;
@@ -512,32 +509,28 @@ static int _wclosedir( _WDIR* dirp ) {
  * Rewind directory stream such that _wreaddir() returns the very first
  * file name again.
  */
-static void _wrewinddir( _WDIR* dirp ) {
-  if ( dirp ) {
+static void _wrewinddir(_WDIR* dirp) {
+  if (dirp) {
     /* Release existing search handle */
-    if ( dirp->handle != INVALID_HANDLE_VALUE ) {
-      FindClose( dirp->handle );
-    }
+    if (dirp->handle != INVALID_HANDLE_VALUE) { FindClose(dirp->handle); }
 
     /* Open new search handle */
-    dirent_first( dirp );
+    dirent_first(dirp);
   }
 }
 
 /* Get first directory entry (internal) */
-static WIN32_FIND_DATAW* dirent_first( _WDIR* dirp ) {
+static WIN32_FIND_DATAW* dirent_first(_WDIR* dirp) {
   WIN32_FIND_DATAW* datap;
 
   /* Open directory and retrieve the first entry */
-  dirp->handle = FindFirstFileW( dirp->patt, &dirp->data );
-  if ( dirp->handle != INVALID_HANDLE_VALUE ) {
-
+  dirp->handle = FindFirstFileW(dirp->patt, &dirp->data);
+  if (dirp->handle != INVALID_HANDLE_VALUE) {
     /* a directory entry is now waiting in memory */
     datap = &dirp->data;
     dirp->cached = 1;
 
   } else {
-
     /* Failed to re-open directory: no directory entry in memory */
     dirp->cached = 0;
     datap = NULL;
@@ -546,31 +539,28 @@ static WIN32_FIND_DATAW* dirent_first( _WDIR* dirp ) {
 }
 
 /* Get next directory entry (internal) */
-static WIN32_FIND_DATAW* dirent_next( _WDIR* dirp ) {
+static WIN32_FIND_DATAW* dirent_next(_WDIR* dirp) {
   WIN32_FIND_DATAW* p;
 
   /* Get next directory entry */
-  if ( dirp->cached != 0 ) {
-
+  if (dirp->cached != 0) {
     /* A valid directory entry already in memory */
     p = &dirp->data;
     dirp->cached = 0;
 
-  } else if ( dirp->handle != INVALID_HANDLE_VALUE ) {
-
+  } else if (dirp->handle != INVALID_HANDLE_VALUE) {
     /* Get the next directory entry from stream */
-    if ( FindNextFileW( dirp->handle, &dirp->data ) != FALSE ) {
+    if (FindNextFileW(dirp->handle, &dirp->data) != FALSE) {
       /* Got a file */
       p = &dirp->data;
     } else {
       /* The very last entry has been processed or an error occured */
-      FindClose( dirp->handle );
+      FindClose(dirp->handle);
       dirp->handle = INVALID_HANDLE_VALUE;
       p = NULL;
     }
 
   } else {
-
     /* End of directory stream reached */
     p = NULL;
   }
@@ -581,29 +571,28 @@ static WIN32_FIND_DATAW* dirent_next( _WDIR* dirp ) {
 /*
  * Open directory stream using plain old C-string.
  */
-static DIR* opendir( const char* dirname ) {
+static DIR* opendir(const char* dirname) {
   struct DIR* dirp;
   int         error;
 
   /* Must have directory name */
-  if ( dirname == NULL || dirname[0] == '\0' ) {
-    dirent_set_errno( ENOENT );
+  if (dirname == NULL || dirname[0] == '\0') {
+    dirent_set_errno(ENOENT);
     return NULL;
   }
 
   /* Allocate memory for DIR structure */
-  dirp = (DIR*)malloc( sizeof( struct DIR ) );
-  if ( dirp ) {
+  dirp = (DIR*)malloc(sizeof(struct DIR));
+  if (dirp) {
     wchar_t wname[PATH_MAX];
     size_t  n;
 
     /* Convert directory name to wide-character string */
-    error = dirent_mbstowcs_s( &n, wname, PATH_MAX, dirname, PATH_MAX );
-    if ( !error ) {
-
+    error = dirent_mbstowcs_s(&n, wname, PATH_MAX, dirname, PATH_MAX);
+    if (!error) {
       /* Open directory stream using wide-character name */
-      dirp->wdirp = _wopendir( wname );
-      if ( dirp->wdirp ) {
+      dirp->wdirp = _wopendir(wname);
+      if (dirp->wdirp) {
         /* Directory stream opened */
         error = 0;
       } else {
@@ -627,8 +616,8 @@ static DIR* opendir( const char* dirname ) {
   }
 
   /* Clean up in case of error */
-  if ( error && dirp ) {
-    free( dirp );
+  if (error && dirp) {
+    free(dirp);
     dirp = NULL;
   }
 
@@ -648,19 +637,19 @@ static DIR* opendir( const char* dirname ) {
  * ANSI strings to the console code page so many non-ASCII characters will
  * display correcly.
  */
-static struct dirent* readdir( DIR* dirp ) {
+static struct dirent* readdir(DIR* dirp) {
   WIN32_FIND_DATAW* datap;
   struct dirent*    entp;
 
   /* Read next directory entry */
-  datap = dirent_next( dirp->wdirp );
-  if ( datap ) {
+  datap = dirent_next(dirp->wdirp);
+  if (datap) {
     size_t n;
     int    error;
 
     /* Attempt to convert file name to multi-byte string */
     error = dirent_wcstombs_s(
-        &n, dirp->ent.d_name, PATH_MAX, datap->cFileName, PATH_MAX );
+      &n, dirp->ent.d_name, PATH_MAX, datap->cFileName, PATH_MAX);
 
     /*
      * If the file name cannot be represented by a multi-byte string,
@@ -672,12 +661,12 @@ static struct dirent* readdir( DIR* dirp ) {
      * name unless the file system provides one.  At least
      * VirtualBox shared folders fail to do this.
      */
-    if ( error && datap->cAlternateFileName[0] != '\0' ) {
+    if (error && datap->cAlternateFileName[0] != '\0') {
       error = dirent_wcstombs_s(
-          &n, dirp->ent.d_name, PATH_MAX, datap->cAlternateFileName, PATH_MAX );
+        &n, dirp->ent.d_name, PATH_MAX, datap->cAlternateFileName, PATH_MAX);
     }
 
-    if ( !error ) {
+    if (!error) {
       DWORD attr;
 
       /* Initialize directory entry for return */
@@ -688,9 +677,9 @@ static struct dirent* readdir( DIR* dirp ) {
 
       /* File attributes */
       attr = datap->dwFileAttributes;
-      if ( ( attr & FILE_ATTRIBUTE_DEVICE ) != 0 ) {
+      if ((attr & FILE_ATTRIBUTE_DEVICE) != 0) {
         entp->d_type = DT_CHR;
-      } else if ( ( attr & FILE_ATTRIBUTE_DIRECTORY ) != 0 ) {
+      } else if ((attr & FILE_ATTRIBUTE_DIRECTORY) != 0) {
         entp->d_type = DT_DIR;
       } else {
         entp->d_type = DT_REG;
@@ -698,7 +687,7 @@ static struct dirent* readdir( DIR* dirp ) {
 
       /* Reset dummy fields */
       entp->d_ino = 0;
-      entp->d_reclen = sizeof( struct dirent );
+      entp->d_reclen = sizeof(struct dirent);
 
     } else {
       /*
@@ -727,21 +716,19 @@ static struct dirent* readdir( DIR* dirp ) {
 /*
  * Close directory stream.
  */
-static int closedir( DIR* dirp ) {
+static int closedir(DIR* dirp) {
   int ok;
-  if ( dirp ) {
-
+  if (dirp) {
     /* Close wide-character directory stream */
-    ok = _wclosedir( dirp->wdirp );
+    ok = _wclosedir(dirp->wdirp);
     dirp->wdirp = NULL;
 
     /* Release multi-byte character version */
-    free( dirp );
+    free(dirp);
 
   } else {
-
     /* Invalid directory stream */
-    dirent_set_errno( EBADF );
+    dirent_set_errno(EBADF);
     ok = /*failure*/ -1;
   }
   return ok;
@@ -750,128 +737,116 @@ static int closedir( DIR* dirp ) {
 /*
  * Rewind directory stream to beginning.
  */
-static void rewinddir( DIR* dirp ) {
+static void rewinddir(DIR* dirp) {
   /* Rewind wide-character string directory stream */
-  _wrewinddir( dirp->wdirp );
+  _wrewinddir(dirp->wdirp);
 }
 
 /* Convert multi-byte string to wide character string */
-static int dirent_mbstowcs_s( size_t*     pReturnValue,
-                              wchar_t*    wcstr,
-                              size_t      sizeInWords,
-                              const char* mbstr,
-                              size_t      count ) {
+static int dirent_mbstowcs_s(size_t*     pReturnValue,
+                             wchar_t*    wcstr,
+                             size_t      sizeInWords,
+                             const char* mbstr,
+                             size_t      count) {
   int error;
 
-#if defined( _MSC_VER ) && _MSC_VER >= 1400
+#  if defined(_MSC_VER) && _MSC_VER >= 1400
 
   /* Microsoft Visual Studio 2005 or later */
-  error = mbstowcs_s( pReturnValue, wcstr, sizeInWords, mbstr, count );
+  error = mbstowcs_s(pReturnValue, wcstr, sizeInWords, mbstr, count);
 
-#else
+#  else
 
   /* Older Visual Studio or non-Microsoft compiler */
   size_t n;
 
   /* Convert to wide-character string (or count characters) */
-  n = mbstowcs( wcstr, mbstr, sizeInWords );
-  if ( !wcstr || n < count ) {
-
+  n = mbstowcs(wcstr, mbstr, sizeInWords);
+  if (!wcstr || n < count) {
     /* Zero-terminate output buffer */
-    if ( wcstr && sizeInWords ) {
-      if ( n >= sizeInWords ) {
-        n = sizeInWords - 1;
-      }
+    if (wcstr && sizeInWords) {
+      if (n >= sizeInWords) { n = sizeInWords - 1; }
       wcstr[n] = 0;
     }
 
     /* Length of resuting multi-byte string WITH zero terminator */
-    if ( pReturnValue ) {
-      *pReturnValue = n + 1;
-    }
+    if (pReturnValue) { *pReturnValue = n + 1; }
 
     /* Success */
     error = 0;
 
   } else {
-
     /* Could not convert string */
     error = 1;
   }
 
-#endif
+#  endif
 
   return error;
 }
 
 /* Convert wide-character string to multi-byte string */
-static int dirent_wcstombs_s( size_t*        pReturnValue,
-                              char*          mbstr,
-                              size_t         sizeInBytes, /* max size of mbstr */
-                              const wchar_t* wcstr,
-                              size_t         count ) {
+static int dirent_wcstombs_s(size_t*        pReturnValue,
+                             char*          mbstr,
+                             size_t         sizeInBytes, /* max size of mbstr */
+                             const wchar_t* wcstr,
+                             size_t         count) {
   int error;
 
-#if defined( _MSC_VER ) && _MSC_VER >= 1400
+#  if defined(_MSC_VER) && _MSC_VER >= 1400
 
   /* Microsoft Visual Studio 2005 or later */
-  error = wcstombs_s( pReturnValue, mbstr, sizeInBytes, wcstr, count );
+  error = wcstombs_s(pReturnValue, mbstr, sizeInBytes, wcstr, count);
 
-#else
+#  else
 
   /* Older Visual Studio or non-Microsoft compiler */
   size_t n;
 
   /* Convert to multi-byte string (or count the number of bytes needed) */
-  n = wcstombs( mbstr, wcstr, sizeInBytes );
-  if ( !mbstr || n < count ) {
-
+  n = wcstombs(mbstr, wcstr, sizeInBytes);
+  if (!mbstr || n < count) {
     /* Zero-terminate output buffer */
-    if ( mbstr && sizeInBytes ) {
-      if ( n >= sizeInBytes ) {
-        n = sizeInBytes - 1;
-      }
+    if (mbstr && sizeInBytes) {
+      if (n >= sizeInBytes) { n = sizeInBytes - 1; }
       mbstr[n] = '\0';
     }
 
     /* Lenght of resulting multi-bytes string WITH zero-terminator */
-    if ( pReturnValue ) {
-      *pReturnValue = n + 1;
-    }
+    if (pReturnValue) { *pReturnValue = n + 1; }
 
     /* Success */
     error = 0;
 
   } else {
-
     /* Cannot convert string */
     error = 1;
   }
 
-#endif
+#  endif
 
   return error;
 }
 
 /* Set errno variable */
-static void dirent_set_errno( int error ) {
-#if defined( _MSC_VER ) && _MSC_VER >= 1400
+static void dirent_set_errno(int error) {
+#  if defined(_MSC_VER) && _MSC_VER >= 1400
 
   /* Microsoft Visual Studio 2005 and later */
-  _set_errno( error );
+  _set_errno(error);
 
-#else
+#  else
 
   /* Non-Microsoft compiler or older Microsoft compiler */
   errno = error;
 
-#endif
+#  endif
 }
 
 
-#ifdef __cplusplus
+#  ifdef __cplusplus
 }
-#endif
+#  endif
 
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
