@@ -1241,7 +1241,8 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc< Instantiation > : public HashFuncBase< Instantiation > {
+  // class HashFunc< Instantiation > : public HashFuncBase< Instantiation > {
+  class HashFunc< Instantiation > : public HashFunc< Size > {
     public:
     /**
      * @brief Computes the hashed value of a key.
@@ -1249,6 +1250,9 @@ namespace gum {
      * @return Returns the hashed value of a key.
      */
     Size operator()(const Instantiation& key) const;
+
+    private:
+    static typename HashFuncCastKey< const DiscreteVariable* >::type __caster;
   };
 } /* namespace gum */
 
